@@ -2,14 +2,14 @@
 #'
 #' This function is designed to prevent specific analysis function executions when the
 #' design conditions are not met. Primarily useful when the \code{analyse} argument to
-#' \code{\link{runSimulation}} was a input as a named list object, however some of the
+#' \code{\link{runSimulation}} was input as a named list object, however some of the
 #' analysis functions are not interesting/compatible with the generated data and should
 #' therefore be skipped.
 #'
 #' @param x logical statement to evaluate. If the statement evaluates to \code{TRUE}
 #'   then the remainder of the defined function will be evaluated
 #'
-#' @param data (optional) the current design condition. This does not need to be supplied
+#' @param condition (optional) the current design condition. This does not need to be supplied
 #'   if the expression in \code{x} evaluates to valid logical (e.g., use \code{Attach(condition)}
 #'   prior to using \code{AnalyseIf}, or use \code{with(condition, AnalyseIf(someLogicalTest))})
 #'
@@ -74,9 +74,9 @@
 #'
 #' }
 #'
-AnalyseIf <- function(x, data = NULL){
+AnalyseIf <- function(x, condition = NULL){
     e <- substitute(x)
-    r <- eval(e, data, parent.frame())
+    r <- eval(e, condition, parent.frame())
     if (!is.logical(r) || length(r) != 1L)
         stop("AnalyseIf must return a single logical value", call.=FALSE)
     if(!isTRUE(r))
