@@ -12,6 +12,11 @@
 #' @param ... a comma separated list of \code{data.frame} or \code{tibble} objects
 #'   containing elements that should be placed in the current working environment
 #'
+#' @param omit an optional character vector containing the names of objects that should not
+#'   be attached to the current environment. For instance, if the objects named 'a' and 'b' should
+#'   not be attached then use \code{omit = c('a', 'b')}.
+#'   When NULL (default) all objects are attached
+#'
 #' @param check logical; check to see if the function will accidentally replace previously defined
 #'   variables with the same names as in \code{condition}? Default is \code{TRUE}, which will avoid
 #'   this error
@@ -66,9 +71,13 @@
 #' }
 #'
 #' }
-Attach <- function(..., check = TRUE, attach_listone = TRUE){
+Attach <- function(..., omit = NULL, check = TRUE, attach_listone = TRUE){
     envir <- as.environment(-1L)
     dots <- list(...)
+    if(!is.null(omit))
+        for(i in length(dots):1L)
+            if(omit %in% names(dots[[i]]))
+                dots[[i]][names(dots[[i]]) %in% omit] <- NULL
     for(i in 1L:length(dots)){
         if(check)
             if(any(ls(envir = envir) %in% names(dots[[i]])))
